==> aplus_chat-0.2.2.tar.gz: lib/core/services/web_services.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:aplus_chat/global.dart';
import 'package:aplus_chat/helper/logger.dart';
import 'package:aplus_chat/helper/network_connection.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:path/path.dart';

class Webservice {
  static postRequest(
      {@required uri,
      baseUrl, // require for login, and other API url get from Login Response
      body,
      header,
      jsonEncoded = true,
      bool hasBearer = false,
      Function(dynamic responseBody)? onSuccess,
      Function(dynamic error)? onFailure,
      Function? onTimeout,
      Function(dynamic connectionFailed)? onConnectionFailed,
      context}) async {
    bool isConnected = await NetworkConnection.isConnectedNetwork();
    if (!isConnected) {
      if (onConnectionFailed != null) {
        onConnectionFailed("Please check you internet connection");
      }
    }

    if (hasBearer) {
      header = {
        'Content-Type': 'application/json',
        'Authorization': 'Bearer',
      };
    } else {
      header ??= {'Content-Type': 'application/json'};
    }

    if (jsonEncoded) {
      body = jsonEncode(body);
    }

    baseUrl ??= Global.baseUrl;
    var url = baseUrl + uri;

    //make sure body should not have integer values, below body accept only String values.
    //make sure here body only accept Map type data till you not set 'Content-Type': 'application/json',
    http.post(Uri.parse(url), body: body, headers: header).then((response) {
      Log.displayResponse(payload: body, res: response, requestType: 'POST');
      var bodyData = jsonDecode(response.body);

      if (onSuccess != null) {
        if (bodyData['success']) {
          onSuccess(response.body);
        } else {
          if (onFailure != null) {
            onFailure(bodyData);
          }
        }
      }
    }).catchError((error) {
      if (onFailure != null) onFailure(error);
    }).timeout(const Duration(seconds: 20), onTimeout: () {
      if (onTimeout != null) onTimeout();
    });
  }

  // static uploadImage({
  //   required uri,
  //   required File file,
  //   Map<String, String>? body,
  //   required String? fileType,
  //   header,
  //   bool hasBearer = false,
  //   required Function onSuccess,
  //   Function? onFailure,
  //   Function? onTimeout,
  //   Function? onConnectionFailed,
  // }) async {
  //   if (hasBearer) {
  //     header = {
  //       'Content-Type': 'application/json',
  //       // 'Authorization': "Bearer ${AppStorages.accessToken}",
  //     };
  //   }
  //
  //   var url = Global.baseApiUrl + uri;
  //   var request = http.MultipartRequest('POST', Uri.parse(url));
  //   if (hasBearer) request.headers.addAll(header);
  //   request.fields.addAll(body!);
  //   debugPrint(file.path);
  //   debugPrint("FILE PATH");
  //   if (file.path.isNotEmpty) {
  //     var stream = http.ByteStream(Stream.castFrom(file.openRead()));
  //     var length = await file.length();
  //     var multipartFile = http.MultipartFile(fileType!, stream, length,
  //         filename: basename(file.path));
  //     request.files.add(multipartFile);
  //   }
  //
  //   await request.send().then((resStream) async {
  //     resStream.stream
  //         .transform(utf8.decoder)
  //         .transform(const LineSplitter())
  //         .listen((response) {
  //       Log.displayResponse(
  //           payload: body, res: response, requestType: 'Upload');
  //       final bodyData = jsonDecode(response);
  //       debugPrint(bodyData);
  //       if (bodyData['status'] == 1) {
  //         onSuccess(response);
  //       } else {
  //         onFailure!(bodyData['message']);
  //       }
  //     });
  //   }).catchError((error) {
  //     debugPrint('Error : catchError $error');
  //     debugPrint(url);
  //     onFailure!(error);
  //   }).timeout(const Duration(seconds: 20), onTimeout: () {
  //     debugPrint(url);
  //     debugPrint('Error : TimeOut');
  //     if (onTimeout != null) onTimeout();
  //   });
  // }

  static uploadMedia({
    required uri,
    required File file,
    required var body,
    required String? fileType,
    header,
    bool hasBearer = false,
    required Function onSuccess,
    Function? onFailure,
    Function? onTimeout,
    Function? onConnectionFailed,
  }) async {
    if (hasBearer) {
      header = {
        'Content-Type': 'application/json',
        // 'Authorization': "Bearer ${AppStorages.accessToken}",
      };
    }
    var url = Global.baseApiUrl + uri;
    var request = http.MultipartRequest('POST', Uri.parse(url));
    debugPrint(url);
    if (hasBearer) request.headers.addAll(header);
    request.fields.addAll(body);
    if (file.path.isNotEmpty) {
      var stream = http.ByteStream(Stream.castFrom(file.openRead()));
      var length = await file.length();
      var multipartFile = http.MultipartFile(fileType!, stream, length,
          filename: basename(file.path));
      request.files.add(multipartFile);
    }
    await request.send().then((resStream) async {
      resStream.stream
          .transform(utf8.decoder)
          .transform(const LineSplitter())
          .listen((response) {
        Log.displayResponse(
            payload: body, res: response, requestType: 'Upload');
        var bodyData = jsonDecode(response);
        if (bodyData["success"]) {
          onSuccess(response);
        } else {
          onFailure!(bodyData);
        }
      });
    }).catchError((error) {
      debugPrint('Error : catchError $error');
      debugPrint(url);
      onFailure!(error);
    }).timeout(const Duration(seconds: 20), onTimeout: () {
      debugPrint(url);
      debugPrint('Error : TimeOut');
      if (onTimeout != null) onTimeout("error");
    });
  }
}

==> aplus_chat-0.2.14.tar.gz: lib/core/services/web_services.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:aplus_chat/global.dart';
import 'package:aplus_chat/helper/logger.dart';
import 'package:aplus_chat/helper/network_connection.dart';
import 'package:aplus_chat/helper/storages.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:path/path.dart';

class Webservice {
  static postRequest(
      {@required uri,
      baseUrl, // require for login, and other API url get from Login Response
      body,
      header,
      jsonEncoded = true,
      bool hasBearer = false,
      Function(dynamic responseBody)? onSuccess,
      Function(dynamic error)? onFailure,
      Function? onTimeout,
      Function(dynamic connectionFailed)? onConnectionFailed,
      context}) async {
    bool isConnected = await NetworkConnection.isConnectedNetwork();
    if (!isConnected) {
      if (onConnectionFailed != null) {
        onConnectionFailed("Please check you internet connection");
      }
    }

    if (hasBearer) {
      header = {
        'Content-Type': 'application/json',
        'Authorization': 'Bearer',
      };
    } else {
      header ??= {'Content-Type': 'application/json'};
    }

    if (jsonEncoded) {
      body = jsonEncode(body);
    }

    baseUrl ??= Global.baseUrl;
    var url = baseUrl + uri;

    //make sure body should not have integer values, below body accept only String values.
    //make sure here body only accept Map type data till you not set 'Content-Type': 'application/json',
    http.post(Uri.parse(url), body: body, headers: header).then((response) {
      Log.displayResponse(payload: body, res: response, requestType: 'POST');
      var bodyData = jsonDecode(response.body);

      if (onSuccess != null) {
        if (bodyData['success']) {
          onSuccess(response.body);
        } else {
          if (onFailure != null) {
            onFailure(bodyData);
          }
        }
      }
    }).catchError((error) {
      if (onFailure != null) onFailure(error);
    }).timeout(const Duration(seconds: 20), onTimeout: () {
      if (onTimeout != null) onTimeout();
    });
  }

  // static uploadImage({
  //   required uri,
  //   required File file,
  //   Map<String, String>? body,
  //   required String? fileType,
  //   header,
  //   bool hasBearer = false,
  //   required Function onSuccess,
  //   Function? onFailure,
  //   Function? onTimeout,
  //   Function? onConnectionFailed,
  // }) async {
  //   if (hasBearer) {
  //     header = {
  //       'Content-Type': 'application/json',
  //       // 'Authorization': "Bearer ${AppStorages.accessToken}",
  //     };
  //   }
  //
  //   var url = Global.baseApiUrl + uri;
  //   var request = http.MultipartRequest('POST', Uri.parse(url));
  //   if (hasBearer) request.headers.addAll(header);
  //   request.fields.addAll(body!);
  //   debugPrint(file.path);
  //   debugPrint("FILE PATH");
  //   if (file.path.isNotEmpty) {
  //     var stream = http.ByteStream(Stream.castFrom(file.openRead()));
  //     var length = await file.length();
  //     var multipartFile = http.MultipartFile(fileType!, stream, length,
  //         filename: basename(file.path));
  //     request.files.add(multipartFile);
  //   }
  //
  //   await request.send().then((resStream) async {
  //     resStream.stream
  //         .transform(utf8.decoder)
  //         .transform(const LineSplitter())
  //         .listen((response) {
  //       Log.displayResponse(
  //           payload: body, res: response, requestType: 'Upload');
  //       final bodyData = jsonDecode(response);
  //       debugPrint(bodyData);
  //       if (bodyData['status'] == 1) {
  //         onSuccess(response);
  //       } else {
  //         onFailure!(bodyData['message']);
  //       }
  //     });
  //   }).catchError((error) {
  //     debugPrint('Error : catchError $error');
  //     debugPrint(url);
  //     onFailure!(error);
  //   }).timeout(const Duration(seconds: 20), onTimeout: () {
  //     debugPrint(url);
  //     debugPrint('Error : TimeOut');
  //     if (onTimeout != null) onTimeout();
  //   });
  // }

  static uploadImage({
    required uri,
    required File file,
    var body,
    required String? fileType,
    header,
    bool hasBearer = false,
    required Function onSuccess,
    Function? onFailure,
    Function? onTimeout,
    Function? onConnectionFailed,
  }) async {

    if (hasBearer) {
      header = {
       // 'Content-Type': 'application/json',
        'secretKey': AppStorages.secKey,
      };
    }
    var url = Global.baseApiUrl + uri;
    var request = http.MultipartRequest('POST', Uri.parse(url));
    if (hasBearer) request.headers.addAll(header);

    request.fields.addAll(body);
    if (file.path.isNotEmpty) {
      var stream = http.ByteStream(Stream.castFrom(file.openRead()));
      var length = await file.length();
      var multipartFile =
      http.MultipartFile(fileType!, stream, length, filename: basename(file.path));
      request.files.add(multipartFile);
    }

    await request.send().then((resStream) async {
      resStream.stream.transform(utf8.decoder).transform(const LineSplitter()).listen((response) {
        Log.displayResponse(payload: body, res: response, requestType: 'Upload');
        final bodyData = jsonDecode(response);
        print(bodyData);
        // hideAppLoader();

        if (bodyData['success'] ) {
          onSuccess(response);
        } else {
          onFailure!(bodyData['message']);
        }
      });
    }).catchError((error) {
      //  hideAppLoader();
      if (kDebugMode) {
        print('Error : catchError $error');
        print(url);
      }
      // getSnackToast(
      //     message: error.toString(),
      //     colorText: Colors.white,
      //     backgroundColor: Colors.red,
      //     duration: const Duration(seconds: 5));
      onFailure!(error);
    }).timeout(const Duration(seconds: 20), onTimeout: () {
      // hideAppLoader();
      if (kDebugMode) {
        print(url);
        print('Error : TimeOut');
      }
      if (onTimeout != null) onTimeout();
    });
  }}
